==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/krita/image/tests/kis_transaction_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <qtest_kde.h>

#include "kis_transaction_test.h"

#include <KoStore.h>
#include <KoColorSpace.h>
#include <KoColorSpaceRegistry.h>

#include "kis_types.h"
#include "kis_paint_device.h"
#include "kis_transaction.h"

void KisTransactionTest::testUndo()
{
    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
    KisPaintDeviceSP dev = new KisPaintDevice( cs );

    quint8* pixel = cs->allocPixelBuffer( 1 );
    cs->fromQColor( Qt::white, pixel );
    dev->fill( 0, 0, 512, 512, pixel);

    cs->fromQColor( Qt::black, pixel );
    dev->fill( 512, 0, 512, 512, pixel );

    QColor c1;
    quint8 opacity1;
    dev->pixel( 5, 5, &c1, &opacity1 );

    QColor c2;
    quint8 opacity2;
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

    KisTransaction t( "mirror", dev, 0 );
    dev->mirrorX();

    t.undo();

    dev->pixel( 5, 5, &c1, &opacity1 );
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

}

void KisTransactionTest::testRedo()
{
    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
    KisPaintDeviceSP dev = new KisPaintDevice( cs );

    quint8* pixel = cs->allocPixelBuffer( 1 );
    cs->fromQColor( Qt::white, pixel );
    dev->fill( 0, 0, 512, 512, pixel);

    cs->fromQColor( Qt::black, pixel );
    dev->fill( 512, 0, 512, 512, pixel );

    QColor c1;
    quint8 opacity1;
    dev->pixel( 5, 5, &c1, &opacity1 );

    QColor c2;
    quint8 opacity2;
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

    KisTransaction t( "mirror", dev, 0 );
    dev->mirrorX();

    t.undo();
    t.redo();

    dev->pixel( 5, 5, &c1, &opacity1 );
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::black );
    QVERIFY( c2 == Qt::white );
}

QTEST_KDEMAIN(KisTransactionTest, GUI)
#include "kis_transaction_test.moc"

==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/krita/image/tests/kis_transaction_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <qtest_kde.h>

#include "kis_transaction_test.h"

#include <KoStore.h>
#include <KoColorSpace.h>
#include <KoColorSpaceRegistry.h>

#include "kis_types.h"
#include "kis_paint_device.h"
#include "kis_transaction.h"

void KisTransactionTest::testUndo()
{
    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
    KisPaintDeviceSP dev = new KisPaintDevice( cs );

    quint8* pixel = cs->allocPixelBuffer( 1 );
    cs->fromQColor( Qt::white, pixel );
    dev->fill( 0, 0, 512, 512, pixel);

    cs->fromQColor( Qt::black, pixel );
    dev->fill( 512, 0, 512, 512, pixel );

    QColor c1;
    quint8 opacity1;
    dev->pixel( 5, 5, &c1, &opacity1 );

    QColor c2;
    quint8 opacity2;
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

    KisTransaction t( "mirror", dev, 0 );
    dev->mirrorX();

    t.undo();

    dev->pixel( 5, 5, &c1, &opacity1 );
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

}

void KisTransactionTest::testRedo()
{
    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
    KisPaintDeviceSP dev = new KisPaintDevice( cs );

    quint8* pixel = cs->allocPixelBuffer( 1 );
    cs->fromQColor( Qt::white, pixel );
    dev->fill( 0, 0, 512, 512, pixel);

    cs->fromQColor( Qt::black, pixel );
    dev->fill( 512, 0, 512, 512, pixel );

    QColor c1;
    quint8 opacity1;
    dev->pixel( 5, 5, &c1, &opacity1 );

    QColor c2;
    quint8 opacity2;
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::white );
    QVERIFY( c2 == Qt::black );

    KisTransaction t( "mirror", dev, 0 );
    dev->mirrorX();

    t.undo();
    t.redo();

    dev->pixel( 5, 5, &c1, &opacity1 );
    dev->pixel( 517, 5, &c2, &opacity2 );

    QVERIFY( c1 == Qt::black );
    QVERIFY( c2 == Qt::white );
}

QTEST_KDEMAIN(KisTransactionTest, GUI)
#include "kis_transaction_test.moc"
